Bip43KeyTree class abstract

m / purpose' / * Reference: BIP-0043

Implemented types
Implementers

Constructors

Bip43KeyTree()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isPrivate → bool
no setterinherited
purpose → int
Purpose, defaults to Bip43 i.e. 43'
no setter
root ↔ Bip32Key
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ckdPriv(Bip32PrivateKey parentSecret, int index) → Bip32PrivateKey
Private parent key to private child key
inherited
ckdPub(Bip32PublicKey parentSecret, int index) → Bip32PublicKey
Public parent key to public child key
inherited
doImport(String key) → Bip32Key
inherited
master(Uint8List seed) → Bip32Key
inherited
neuterPriv(Bip32PrivateKey parentSecret) → Bip32PublicKey
Private parent key to public Child key
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathToKey(String path) → Bip32Key
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited