Cip1854KeyTree class abstract

m / purpose' / coin_type' / account' / role / index Reference: CIP-1854

Inheritance

Constructors

Cip1854KeyTree()

Properties

account → int
Account, defaults to 0' the first account index
no setterinherited
addressIndex → int
Address Index, defaults to the first address key
finalinherited
change → int
Change, defaults to the external keys
no setterinherited
coinType → int
Coin Type, defaults to 0' the Bitcoin. Not used in Cardano
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isPrivate → bool
no setterinherited
purpose → int
Purpose, defaults to Bip44 i.e. 44'
final
role ↔ int
getter/setter pairinherited
root ↔ Bip32Key
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ckdPriv(Bip32PrivateKey parentSecret, int index) → Bip32PrivateKey
Private parent key to private child key
inherited
ckdPub(Bip32PublicKey parentSecret, int index) → Bip32PublicKey
Public parent key to public child key
inherited
doImport(String key) → Bip32Key
inherited
master(Uint8List seed) → Bip32Key
inherited
neuterPriv(Bip32PrivateKey parentSecret) → Bip32PublicKey
Private parent key to public Child key
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathToKey(String path) → Bip32Key
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

stakingKey → int
final